# frozen_string_literal: true
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/date.proto

require 'google/protobuf'


descriptor_data = "\n\x16google/type/date.proto\x12\x0bgoogle.type\"0\n\x04\x44\x61te\x12\x0c\n\x04year\x18\x01 \x01(\x05\x12\r\n\x05month\x18\x02 \x01(\x05\x12\x0b\n\x03\x64\x61y\x18\x03 \x01(\x05\x42Z\n\x0f\x63om.google.typeB\tDateProtoP\x01Z4google.golang.org/genproto/googleapis/type/date;date\xa2\x02\x03GTPb\x06proto3"

pool = ::Google::Protobuf::DescriptorPool.generated_pool
pool.add_serialized_file(descriptor_data)

module Google
  module Type
    Date = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("google.type.Date").msgclass
  end
end

#### Source proto file: google/type/date.proto ####
#
# // Copyright 2026 Google LLC
# //
# // Licensed under the Apache License, Version 2.0 (the "License");
# // you may not use this file except in compliance with the License.
# // You may obtain a copy of the License at
# //
# //     http://www.apache.org/licenses/LICENSE-2.0
# //
# // Unless required by applicable law or agreed to in writing, software
# // distributed under the License is distributed on an "AS IS" BASIS,
# // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# // See the License for the specific language governing permissions and
# // limitations under the License.
#
# syntax = "proto3";
#
# package google.type;
#
# option go_package = "google.golang.org/genproto/googleapis/type/date;date";
# option java_multiple_files = true;
# option java_outer_classname = "DateProto";
# option java_package = "com.google.type";
# option objc_class_prefix = "GTP";
#
# // Represents a whole or partial calendar date, such as a birthday. The time of
# // day and time zone are either specified elsewhere or are insignificant. The
# // date is relative to the Gregorian Calendar. This can represent one of the
# // following:
# //
# // * A full date, with non-zero year, month, and day values.
# // * A month and day, with a zero year (for example, an anniversary).
# // * A year on its own, with a zero month and a zero day.
# // * A year and month, with a zero day (for example, a credit card expiration
# //   date).
# //
# // Related types:
# //
# // * [google.type.TimeOfDay][google.type.TimeOfDay]
# // * [google.type.DateTime][google.type.DateTime]
# // * [google.protobuf.Timestamp][google.protobuf.Timestamp]
# message Date {
#   // Year of the date. Must be from 1 to 9999, or 0 to specify a date without
#   // a year.
#   int32 year = 1;
#
#   // Month of a year. Must be from 1 to 12, or 0 to specify a year without a
#   // month and day.
#   int32 month = 2;
#
#   // Day of a month. Must be from 1 to 31 and valid for the year and month, or 0
#   // to specify a year by itself or a year and month where the day isn't
#   // significant.
#   int32 day = 3;
# }
