# frozen_string_literal: true
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/type/localized_text.proto

require 'google/protobuf'


descriptor_data = "\n google/type/localized_text.proto\x12\x0bgoogle.type\"4\n\rLocalizedText\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x15\n\rlanguage_code\x18\x02 \x01(\tBw\n\x0f\x63om.google.typeB\x12LocalizedTextProtoP\x01ZHgoogle.golang.org/genproto/googleapis/type/localized_text;localized_text\xa2\x02\x03GTPb\x06proto3"

pool = ::Google::Protobuf::DescriptorPool.generated_pool
pool.add_serialized_file(descriptor_data)

module Google
  module Type
    LocalizedText = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("google.type.LocalizedText").msgclass
  end
end

#### Source proto file: google/type/localized_text.proto ####
#
# // Copyright 2026 Google LLC
# //
# // Licensed under the Apache License, Version 2.0 (the "License");
# // you may not use this file except in compliance with the License.
# // You may obtain a copy of the License at
# //
# //     http://www.apache.org/licenses/LICENSE-2.0
# //
# // Unless required by applicable law or agreed to in writing, software
# // distributed under the License is distributed on an "AS IS" BASIS,
# // WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# // See the License for the specific language governing permissions and
# // limitations under the License.
#
# syntax = "proto3";
#
# package google.type;
#
# option go_package = "google.golang.org/genproto/googleapis/type/localized_text;localized_text";
# option java_multiple_files = true;
# option java_outer_classname = "LocalizedTextProto";
# option java_package = "com.google.type";
# option objc_class_prefix = "GTP";
#
# // Localized variant of a text in a particular language.
# message LocalizedText {
#   // Localized string in the language corresponding to
#   // [language_code][google.type.LocalizedText.language_code] below.
#   string text = 1;
#
#   // The text's BCP-47 language code, such as "en-US" or "sr-Latn".
#   //
#   // For more information, see
#   // http://www.unicode.org/reports/tr35/#Unicode_locale_identifier.
#   string language_code = 2;
# }
